@@ -152,6 +152,9 @@ static void zgcatl(void);
 
 static char fontlist[255] = { 41, 42, 43, 44, 55, 66, 77, 85, 95 };
 
+//  Full Color index */
+static double rt2,gt2,bt2,rl2,gl2,bl2;
+static int ifcidx=998;
 
 /* For using system font. some internal variables of SGPACK*/
 static int sg_lfprop, sg_lcntl, sg_isup, sg_isub, sg_irst;
@@ -1050,10 +1053,15 @@ void ZGSCLI(DCL_INT *iclidx)
 
   iclidz = *iclidx % MAXCLI;
 
-  rt1 = (double) cx[iclidz].red   / 65535;
-  gt1 = (double) cx[iclidz].green / 65535;
-  bt1 = (double) cx[iclidz].blue  / 65535;
-
+  if(*iclidx==ifcidx){
+    rt1=rl2;
+    gt1=gl2;
+    bt1=bl2;
+  }else{
+    rt1 = (double) cx[iclidz].red   / 65535;
+    gt1 = (double) cx[iclidz].green / 65535;
+    bt1 = (double) cx[iclidz].blue  / 65535;
+  }
   cairo_set_source_rgb(cr,rt1,gt1,bt1);
   }
 /*if (iclidz == 0)
@@ -2125,7 +2133,7 @@ void ZGGTON(DCL_INT *np, DCL_REAL wpx[], DCL_REAL wpy[], DCL_INT *itpat)
   //  ibit = *itpat % 1000;
   iclr = (*itpat / 1000) % MAXCLI;
 
-  if ((*itpat / 1000) == 999){
+  if ((*itpat / 1000) == ifcidx){
     rt1=rt2;
     gt1=gt2;
     bt1=bt2;
@@ -2395,17 +2403,17 @@ void ZGSLCL(DCL_INT *icolor)
 {
   GdkColor loccx;
 
-  double rt1,gt1,bt1;
+//  double rt1,gt1,bt1;
 
   loccx.red   = ((*icolor >> 16) & 255) * 256;
   loccx.green = ((*icolor >> 8)  & 255) * 256;
   loccx.blue  = ((*icolor >> 0)  & 255) * 256;
 
-  rt1 = (double) loccx.red   / 65535;
-  gt1 = (double) loccx.green / 65535;
-  bt1 = (double) loccx.blue  / 65535;
+  rl2 = (double) loccx.red   / 65535;
+  gl2 = (double) loccx.green / 65535;
+  bl2 = (double) loccx.blue  / 65535;
 
-  cairo_set_source_rgb(cr,rt1,gt1,bt1);
+  cairo_set_source_rgb(cr,rl2,gl2,bl2);
 }
 
 #ifndef WINDOWS
